Over-sampling Samplers — imbalanced-ensemble 0.1.0 documentation

# Over-sampling Samplers

The `imbalanced_ensemble.sampler.over_sampling` submodule provides a set of methods to perform over-sampling.

`ADASYN`(**kwargs) | Oversample using Adaptive Synthetic (ADASYN) algorithm.
`RandomOverSampler`(**kwargs) | Class to perform random over-sampling.
`KMeansSMOTE`(**kwargs) | Apply a KMeans clustering before to over-sample using SMOTE.
`SMOTE`(**kwargs) | Class to perform over-sampling using SMOTE.
`BorderlineSMOTE`(**kwargs) | Over-sampling using Borderline SMOTE.
`SVMSMOTE`(**kwargs) | Over-sampling using SVM-SMOTE.